---
title: "Point Clouds"
---

<figure markdown>
  ![Point Cloud Example](../_img/point_cloud_cad_example.jpeg){ width="400" }
  <figcaption>Point Cloud of a CAD model</figcaption>
</figure>

A Point Cloud is a simple collection of points in $\mathbb{R}^3$

:::mouette.mesh.datatypes.pointcloud